/**************************************************************************
**  (c) Copyright 2002, Andromeda Technology & Automation
***************************************************************************
** MODULE INFORMATION *
***********************
**      FILE NAME      : configuration.h
**      SYSTEM NAME    : ACL - Andromeda class Library
**      VERSION NUMBER : $Revision: 1.4 $
**
**  DESCRIPTION      : Definition of configuration class 
**
**  EXPORTED OBJECTS : class configuration
**  LOCAL    OBJECTS : 
**  MODULES  USED    : String, XML
***************************************************************************
**  ADMINISTRATIVE INFORMATION *
********************************
**      ORIGINAL AUTHOR : Arjen Baart - arjen@andromeda.nl
**      CREATION DATE   : Nov 02, 2002
**      LAST UPDATE     : 
**      MODIFICATIONS   : 
**************************************************************************/


#ifndef CONFIGURATION_H
#define CONFIGURATION_H

#include <libxml/parser.h>   // usually in /usr/include/libxml2, see xml2-config

#include "String.h"

/*
///////////////////////////////////////////////////////////////////////////
//  NAME           : configuration
//  BASECLASS      :
//  MEMBERS        : 
//  OPERATORS      :
//  METHODS        : read
//                   find_parameter
//
//  DESCRIPTION    : Handle configurational parameters for the application.
//                   Many applications need some permanently stored configurational
//                   data. The information is usually stored in two places: A system-
//                   wide configuration file and a configuration file per user.
//                   The content of the configuration file is in XML format.
//                   The configuration base class takes care of finding the configuration
//                   files, e.g. in /etc/app.conf or in /usr/local/etc/app.conf, along
//                   with the configuration file in the user's home directory.
//                   The config files are parsed with the gnome XML parser and a
//                   framework is provided to find configurational items.
//
//  RELATIONS      : 
//  SEE ALSO       :
//  LAST MODIFIED  : Apr 13, 2007
///////////////////////////////////////////////////////////////////////////
*/

class configuration
{

   xmlDocPtr     system;   // The system-wide config tree
   xmlDocPtr     user;     // User-specific config tree
   String        app_name; // Name of the application and XML root element

   xmlNodePtr    xmlFindTag(xmlNodePtr, const String, int n = 0);

public:

   configuration()
   {
      system  = NULL;
      user    = NULL;
      app_name = "ACL";
   }

   //  Find the config files and parse the XML

   bool read(const String name);

   //  Return the value of a config parameter

   String find_parameter(const String section, const String parameter, int sec_n = 0, int param_n = 0);

};

#endif // CONFIGURATION_H
