/*******************************************************
 *  Unit test for the UTC class
 *
 * test conversion and formatting of UTC objects
 ******************************************************
 *
 */

#include "date.h"
#include <assert.h>

int main()
{
   String formatted;

   date d1(15, 9, 2002);
   hour h1(15, 23, 46);

   UTC  u1(d1, h1);

   std::cout << "Contructor with date = 15-9-2002, hour = 15:23:46: " << u1 << "\n";
   formatted = u1.format();
   std::cout << "Formatted with default format: " << formatted << "\n";
   assert(formatted == "2002-09-15 15:23:46");


   String s3("23-10-2019 23:45");
   UTC    u3(s3);

   std::cout << "Contructor from String " << s3 << " : " << u3 << "\n";
   formatted = u3.format();
   std::cout << "Formatted with default format: " << formatted << "\n";
   assert(formatted == "2019-10-23 23:45:00");


   String s4("22-10-2020 16:40");
   UTC    u4(s4);
   time_t t4;

   std::cout << "Contructor from String " << s4 << " : " << u4 << "\n";
   t4 = u4.to_time_t();
   std::cout << "Converted to time_t: " << t4 << " seconds since Epoch\n";
   assert(t4 == 1603377600);

   UTC u5(t4);
   std::cout << "Constructed from time_t " << t4 << " :  " << u5 << "\n";
   assert(u5 == u4);

   UTC u6;
   u6 = t4;
   std::cout << "Assigned from time_t " << t4 << " :  " << u6 << "\n";
   assert(u6 == u4);

   return 0;
}

