/****************************************************************
 *  Unit test for the UTC class
 *
 * test the date and time parser that converts String to UTC
 ***************************************************************
 *
 */

#include "date.h"
#include <assert.h>

int main()
{
   UTC   u0;
   String the_date;


   the_date = "20120208 113456";
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(8, 2, 2012));
   assert(hour(u0) == hour(11, 34, 56));

   the_date = "2012-02-08";
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(8, 2, 2012));
   assert(hour(u0) == hour(0, 0, 0));

   the_date = "2012-02-08 11:34";
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(8, 2, 2012));
   assert(hour(u0) == hour(11, 34, 0));

   the_date = "2012-02-08 11:34:56";
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(8, 2, 2012));
   assert(hour(u0) == hour(11, 34, 56));

   the_date = "2012 02 08 11.34.56";
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(8, 2, 2012));
   assert(hour(u0) == hour(11, 34, 56));

   the_date = "08-02-2012";
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(8, 2, 2012));

   the_date = "02/08/2012";
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(8, 2, 2012));

   the_date = "Feb 8 2012";
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(8, 2, 2012));

   the_date = "2012 Feb 8";
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(8, 2, 2012));

   the_date = "8 FEB 2012";
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(8, 2, 2012));

   the_date = "2012 8 feb";
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(8, 2, 2012));

   the_date = "8 February 2012 15:00";
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(8, 2, 2012));
   assert(hour(u0) == hour(15, 0, 0));

   the_date = "Sun Jun 16 13:02:56 CEST 2019";   // A UNIX date string
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(16, 6, 2019));
   assert(hour(u0) == hour(13, 2, 56));

   the_date = "Wed Sep 09 16:40:03.634357 2020";   // A UNIX date string with fractional seconds
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(9, 9, 2020));
   assert(hour(u0) == hour(16, 40, 3));

   //  Without a year: year = -1
   the_date = "8 February";
   u0 = UTC(the_date);
   std::cout << "String \"" << the_date << "\" converts to: \"" << u0 << "\"\n";
   assert(date(u0) == date(8, 2, -1));

   //  TODO: test for invalid dates and syntax errors

   return 0;
}

